@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "fpga" "0.3.0"
+(define-package "fpga" "20251002.1238"
   "FPGA & ASIC Utils."
   '((emacs "29.1"))
   :url "https://github.com/gmlarumbe/fpga"
-  :commit "9f014c09d132f60fe5fe76356acf78affa2e2bdc"
-  :revdesc "9f014c09d132"
+  :commit "8e5f44d73d9bec693b9882113fa34827a5b4c2b1"
+  :revdesc "8e5f44d73d9b"
   :keywords '("tools")
   :authors '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com"))
   :maintainers '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com")))
